@@ -468,20 +468,23 @@ where
             query_env: &env,
         };
 
-        let value = match &env.operation.node.ty {
+        let res = match &env.operation.node.ty {
             OperationType::Query => resolve_container(&ctx, &self.query).await,
             OperationType::Mutation => resolve_container_serial(&ctx, &self.mutation).await,
-            OperationType::Subscription => {
-                return Response::from_errors(vec![ServerError::new(
-                    "Subscriptions are not supported on this transport.",
-                    None,
-                )]);
-            }
+            OperationType::Subscription => Err(ServerError::new(
+                "Subscriptions are not supported on this transport.",
+                None,
+            )),
         };
 
-        let mut resp = Response::new(value)
-            .http_headers(std::mem::take(&mut *env.http_headers.lock().unwrap()));
-        resp.errors = std::mem::take(&mut env.errors.lock().unwrap());
+        let mut resp = match res {
+            Ok(value) => Response::new(value)
+                .http_headers(std::mem::take(&mut *env.http_headers.lock().unwrap())),
+            Err(err) => Response::from_errors(vec![err]),
+        };
+
+        resp.errors
+            .extend(std::mem::take(&mut *env.errors.lock().unwrap()));
         resp
     }
 
